@@ -6,17 +6,17 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_delete.php,v 1.38 2004/08/04 15:02:21 vboctor Exp $
+	# $Id: bug_delete.php,v 1.40 2005/07/25 16:34:10 thraxisp Exp $
 	# --------------------------------------------------------
 ?>
 <?php
-	# Deletes the bug and re-directs to view_all_bug_page.php 
+	# Deletes the bug and re-directs to view_all_bug_page.php
 ?>
 <?php
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'bug_api.php' );
 ?>
 <?php
@@ -24,10 +24,17 @@
 
 	access_ensure_bug_level( config_get( 'delete_bug_threshold' ), $f_bug_id );
 
-	helper_ensure_confirmed( lang_get( 'delete_bug_sure_msg' ), lang_get( 'delete_bug_button' ) );
-	
 	$t_bug = bug_get( $f_bug_id, true );
-	
+	if( $t_bug->project_id != helper_get_current_project() ) {
+		# in case the current project is not the same project of the bug we are viewing...
+		# ... override the current project. This to avoid problems with categories and handlers lists etc.
+		$g_project_override = $t_bug->project_id;
+	}
+
+	helper_ensure_confirmed( lang_get( 'delete_bug_sure_msg' ), lang_get( 'delete_bug_button' ) );
+
+	$t_bug = bug_get( $f_bug_id, true );
+
 	helper_call_custom_function( 'issue_delete_validate', array( $f_bug_id ) );
 
 	bug_delete( $f_bug_id );
@@ -35,4 +42,4 @@
 	helper_call_custom_function( 'issue_delete_notify', array( $f_bug_id ) );
 
 	print_successful_redirect( 'view_all_bug_page.php' );
-?>
\ No newline at end of file
+?>
