@@ -6,14 +6,14 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_view_page.php,v 1.70 2004/10/17 00:14:27 thraxisp Exp $
+	# $Id: bug_view_page.php,v 1.77.6.1.4.1 2007/03/06 07:00:33 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'bug_api.php' );
 	require_once( $t_core_path.'custom_field_api.php' );
 	require_once( $t_core_path.'compress_api.php' );
@@ -26,14 +26,22 @@
 	$f_bug_id	= gpc_get_int( 'bug_id' );
 	$f_history	= gpc_get_bool( 'history', config_get( 'history_default_visible' ) );
 
-	if ( ADVANCED_ONLY == config_get( 'show_view' ) ) {
-		print_header_redirect ( 'bug_view_advanced_page.php?bug_id=' . $f_bug_id );
-	}
+	bug_ensure_exists( $f_bug_id );
 
 	access_ensure_bug_level( VIEWER, $f_bug_id );
 
 	$t_bug = bug_prepare_display( bug_get( $f_bug_id, true ) );
 
+	if( $t_bug->project_id != helper_get_current_project() ) {
+		# in case the current project is not the same project of the bug we are viewing...
+		# ... override the current project. This to avoid problems with categories and handlers lists etc.
+		$g_project_override = $t_bug->project_id;
+	}
+
+	if ( ADVANCED_ONLY == config_get( 'show_view' ) ) {
+		print_header_redirect ( 'bug_view_advanced_page.php?bug_id=' . $f_bug_id );
+	}
+
 	$t_access_level_needed = config_get( 'view_history_threshold' );
 	$t_can_view_history = access_has_bug_level( $t_access_level_needed, $f_bug_id );
 
@@ -72,13 +80,13 @@
 
 	<!-- prev/next links -->
 	<?php if( $t_bugslist ) { ?>
-	<td class="center"><span class="small"> 			
-		<?php 
+	<td class="center"><span class="small">
+		<?php
 			$t_bugslist = explode( ',', $t_bugslist );
 			$t_index = array_search( $f_bug_id, $t_bugslist );
 			if( false !== $t_index ) {
-				if( isset( $t_bugslist[$t_index-1] ) ) print_bracket_link( 'bug_view_page.php?bug_id='.$t_bugslist[$t_index-1], '&lt;&lt;' ); 
-				if( isset( $t_bugslist[$t_index+1] ) ) print_bracket_link( 'bug_view_page.php?bug_id='.$t_bugslist[$t_index+1], '&gt;&gt;' ); 
+				if( isset( $t_bugslist[$t_index-1] ) ) print_bracket_link( 'bug_view_page.php?bug_id='.$t_bugslist[$t_index-1], '&lt;&lt;' );
+				if( isset( $t_bugslist[$t_index+1] ) ) print_bracket_link( 'bug_view_page.php?bug_id='.$t_bugslist[$t_index+1], '&gt;&gt;' );
 			}
 		?>
 	</span></td>
@@ -138,7 +146,7 @@
 	<!-- Category -->
 	<td>
 		<?php
-			$t_project_name = project_get_field( $t_bug->project_id, 'name' );
+			$t_project_name = string_display( project_get_field( $t_bug->project_id, 'name' ) );
 			echo "[$t_project_name] $t_bug->category";
 		?>
 	</td>
@@ -201,7 +209,11 @@
 		<?php echo lang_get( 'assigned_to' ) ?>
 	</td>
 	<td colspan="5">
-		<?php print_user_with_subject( $t_bug->handler_id, $f_bug_id ) ?>
+		<?php 
+			if ( access_has_bug_level( config_get( 'view_handler_threshold' ), $f_bug_id ) ) {
+				print_user_with_subject( $t_bug->handler_id, $f_bug_id ); 
+			}
+		?>
 	</td>
 </tr>
 
@@ -254,12 +266,28 @@
 	?>
 
 	<!-- Product Version -->
+	<?php
+		$t_show_version = ( ON == config_get( 'show_product_version' ) )
+			|| ( ( AUTO == config_get( 'show_product_version' ) )
+					&& ( count( version_get_all_rows( $t_bug->project_id ) ) > 0 ) );
+		if ( $t_show_version ) {
+	?>
 	<td class="category">
 		<?php echo lang_get( 'product_version' ) ?>
 	</td>
 	<td>
 		<?php echo $t_bug->version ?>
 	</td>
+	<?php
+		} else {
+	?>
+	<td>
+	</td>
+	<td>
+	</td>
+	<?php
+		}
+	?>
 </tr>
 
 
@@ -319,7 +347,7 @@
 ?>
 	<tr <?php echo helper_alternate_class() ?>>
 		<td class="category">
-			<?php echo lang_get_defaulted( $t_def['name'] ) ?>
+			<?php echo string_display( lang_get_defaulted( $t_def['name'] ) ) ?>
 		</td>
 		<td colspan="5">
 			<?php print_custom_field_value( $t_def, $t_id, $f_bug_id ); ?>
@@ -409,6 +437,6 @@
 	if ( $f_history ) {
 		include( $t_mantis_dir . 'history_inc.php' );
 	}
-	
+
 	html_page_bottom1( __FILE__ );
 ?>
