@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bugnote_edit_page.php,v 1.47 2004/08/27 00:29:54 thraxisp Exp $
+	# $Id: bugnote_edit_page.php,v 1.49 2005/07/25 16:34:10 thraxisp Exp $
 	# --------------------------------------------------------
 
 	# CALLERS
@@ -22,9 +22,9 @@
 ?>
 <?php
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'bug_api.php' );
 	require_once( $t_core_path.'bugnote_api.php' );
 	require_once( $t_core_path.'string_api.php' );
@@ -32,18 +32,25 @@
 ?>
 <?php
 	$f_bugnote_id = gpc_get_int( 'bugnote_id' );
+	$t_bug_id = bugnote_get_field( $f_bugnote_id, 'bug_id' );
+
+	$t_bug = bug_get( $t_bug_id, true );
+	if( $t_bug->project_id != helper_get_current_project() ) {
+		# in case the current project is not the same project of the bug we are viewing...
+		# ... override the current project. This to avoid problems with categories and handlers lists etc.
+		$g_project_override = $t_bug->project_id;
+	}
 
 	# Check if the current user is allowed to edit the bugnote
 	$t_user_id = auth_get_current_user_id();
 	$t_reporter_id = bugnote_get_field( $f_bugnote_id, 'reporter_id' );
 
-	if ( ( $t_user_id != $t_reporter_id ) || 
+	if ( ( $t_user_id != $t_reporter_id ) ||
 	 	( OFF == config_get( 'bugnote_allow_user_edit_delete' ) ) ) {
 		access_ensure_bugnote_level( config_get( 'update_bugnote_threshold' ), $f_bugnote_id );
 	}
 
 	# Check if the bug is readonly
-	$t_bug_id = bugnote_get_field( $f_bugnote_id, 'bug_id' );
 	if ( bug_is_readonly( $t_bug_id ) ) {
 		error_parameters( $t_bug_id );
 		trigger_error( ERROR_BUG_READ_ONLY_ACTION_DENIED, ERROR );
