@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_api.php,v 1.88 2004/11/30 11:11:05 vboctor Exp $
+	# $Id: bug_api.php,v 1.95.8.1.6.1 2006/04/18 00:53:04 thraxisp Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -51,6 +51,7 @@
 		var $view_state = VS_PUBLIC;
 		var $summary = '';
 		var $sponsorship_total = 0;
+		var $sticky = 0;
 
 		# omitted:
 		# var $bug_text_id
@@ -260,6 +261,7 @@
 
 		return true;
 	}
+
 	# --------------------
 	# Validate workflow state to see if bug can be moved to requested state
 	function bug_check_workflow( $p_bug_status, $p_wanted_status ) {
@@ -268,6 +270,9 @@
 		if ( count( $t_status_enum_workflow ) < 1) {
 			# workflow not defined, use default enum
 			return true;
+		} else if ( $p_bug_status == $p_wanted_status ) {
+			# no change in state, allow the transition
+			return true;
 		} else {
 			# workflow defined - find allowed states
 			$t_allowed_states = $t_status_enum_workflow[$p_bug_status];
@@ -314,7 +319,8 @@
 		$c_view_state			= db_prepare_int( $p_bug_data->view_state );
 		$c_steps_to_reproduce	= db_prepare_string( $p_bug_data->steps_to_reproduce );
 		$c_additional_info		= db_prepare_string( $p_bug_data->additional_information );
-		$c_sponsorship_total = 0;
+		$c_sponsorship_total 	= 0;
+		$c_sticky 				= 0;
 
 		# Summary cannot be blank
 		if ( is_blank( $c_summary ) ) {
@@ -383,7 +389,7 @@
 				      os, os_build,
 				      platform, version,
 				      build,
-				      profile_id, summary, view_state, sponsorship_total )
+				      profile_id, summary, view_state, sponsorship_total, sticky, fixed_in_version )
 				  VALUES
 				    ( '$c_project_id',
 				      '$c_reporter_id', '$c_handler_id',
@@ -396,7 +402,7 @@
 				      '$c_os', '$c_os_build',
 				      '$c_platform', '$c_version',
 				      '$c_build',
-				      '$c_profile_id', '$c_summary', '$c_view_state', '$c_sponsorship_total' )";
+				      '$c_profile_id', '$c_summary', '$c_view_state', '$c_sponsorship_total', '$c_sticky', '' )";
 		db_query( $query );
 
 		$t_bug_id = db_insert_id($t_bug_table);
@@ -404,6 +410,10 @@
 		# log new bug
 		history_log_event_special( $t_bug_id, NEW_BUG );
 
+		# log changes, if any (compare happens in history_log_event_direct)
+		history_log_event_direct( $t_bug_id, 'status', config_get( 'bug_submit_status' ), $t_status );
+		history_log_event_direct( $t_bug_id, 'handler_id', 0, $c_handler_id );
+
 		return $t_bug_id;
 	}
 
@@ -454,6 +464,7 @@
 		bug_set_field( $t_new_bug_id, 'eta', $t_bug_data->eta );
 		bug_set_field( $t_new_bug_id, 'fixed_in_version', $t_bug_data->fixed_in_version );
 		bug_set_field( $t_new_bug_id, 'sponsorship_total', 0 );
+		bug_set_field( $t_new_bug_id, 'sticky', 0 );
 
 		# COPY CUSTOM FIELDS
 		if ( $p_copy_custom_fields ) {
@@ -711,6 +722,10 @@
 			}
 		}
 
+		if( !is_blank( $p_bug_data->duplicate_id ) && ( $p_bug_data->duplicate_id != 0 ) && ( $p_bug_id == $p_bug_data->duplicate_id ) ) {
+			trigger_error( ERROR_BUG_DUPLICATE_SELF, ERROR );  # never returns
+	    }
+
 		$t_old_data = bug_get( $p_bug_id, true );
 
 		$t_bug_table = config_get( 'mantis_bug_table' );
@@ -741,7 +756,8 @@
 					fixed_in_version='$c_bug_data->fixed_in_version',
 					view_state='$c_bug_data->view_state',
 					summary='$c_bug_data->summary',
-					sponsorship_total='$c_bug_data->sponsorship_total'
+					sponsorship_total='$c_bug_data->sponsorship_total',
+					sticky='$c_bug_data->sticky'
 				WHERE id='$c_bug_id'";
 		db_query( $query );
 
@@ -769,6 +785,7 @@
 		history_log_event_direct( $p_bug_id, 'view_state', $t_old_data->view_state, $p_bug_data->view_state );
 		history_log_event_direct( $p_bug_id, 'summary', $t_old_data->summary, $p_bug_data->summary );
 		history_log_event_direct( $p_bug_id, 'sponsorship_total', $t_old_data->sponsorship_total, $p_bug_data->sponsorship_total );
+		history_log_event_direct( $p_bug_id, 'sticky', $t_old_data->sticky, $p_bug_data->sticky );
 
 		# Update extended info if requested
 		if ( $p_update_extended ) {
@@ -980,6 +997,35 @@
 		return $t_stats;
 	}
 
+	# --------------------
+	# Get array of attachments associated with the specified bug id.  The array will be
+	# sorted in terms of date added (ASC).  The array will include the following fields:
+	# id, title, diskfile, filename, filesize, file_type, date_added.
+	function bug_get_attachments( $p_bug_id ) {
+		if ( !file_can_view_bug_attachments( $p_bug_id ) ) {
+	        return;
+		}
+
+		$c_bug_id = db_prepare_int( $p_bug_id );
+
+		$t_bug_file_table = config_get( 'mantis_bug_file_table' );
+
+		$query = "SELECT id, title, diskfile, filename, filesize, file_type, date_added
+		                FROM $t_bug_file_table
+		                WHERE bug_id='$c_bug_id'
+		                ORDER BY date_added";
+		$db_result = db_query( $query );
+		$num_notes = db_num_rows( $db_result );
+
+		$t_result = array();
+
+		for ( $i = 0; $i < $num_notes; $i++ ) {
+			$t_result[] = db_fetch_array( $db_result );
+		}
+
+		return $t_result;
+	}
+
 	#===================================
 	# Data Modification
 	#===================================
@@ -1023,7 +1069,7 @@
 
 	# --------------------
 	# assign the bug to the given user
-	function bug_assign( $p_bug_id, $p_user_id, $p_bugnote_text='' ) {
+	function bug_assign( $p_bug_id, $p_user_id, $p_bugnote_text='', $p_bugnote_private = false ) {
 		$c_bug_id	= db_prepare_int( $p_bug_id );
 		$c_user_id	= db_prepare_int( $p_user_id );
 
@@ -1058,7 +1104,7 @@
 
 			# Add bugnote if supplied
 			if ( !is_blank( $p_bugnote_text ) ) {
-				bugnote_add( $p_bug_id, $p_bugnote_text );
+				bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
 			}
 
 			# updated the last_updated date
@@ -1075,14 +1121,14 @@
 
 	# --------------------
 	# close the given bug
-	function bug_close( $p_bug_id, $p_bugnote_text = '' ) {
+	function bug_close( $p_bug_id, $p_bugnote_text = '', $p_bugnote_private = false ) {
 		$p_bugnote_text = trim( $p_bugnote_text );
 
 		bug_set_field( $p_bug_id, 'status', CLOSED );
 
 		# Add bugnote if supplied
 		if ( !is_blank( $p_bugnote_text ) ) {
-			bugnote_add( $p_bug_id, $p_bugnote_text );
+			bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
 		}
 
 		email_close( $p_bug_id );
@@ -1098,11 +1144,14 @@
 
 	# --------------------
 	# resolve the given bug
-	function bug_resolve( $p_bug_id, $p_resolution, $p_fixed_in_version = '', $p_bugnote_text = '', $p_duplicate_id = null, $p_handler_id = null ) {
+	function bug_resolve( $p_bug_id, $p_resolution, $p_fixed_in_version = '', $p_bugnote_text = '', $p_duplicate_id = null, $p_handler_id = null, $p_bugnote_private = false ) {
 		$p_bugnote_text = trim( $p_bugnote_text );
 
 		if( !is_blank( $p_duplicate_id ) && ( $p_duplicate_id != 0 ) ) {
 			# MASC RELATIONSHIP
+			if ( $p_bug_id == $p_duplicate_id ) {
+			    trigger_error( ERROR_BUG_DUPLICATE_SELF, ERROR );  # never returns
+			}
 
 			# the related bug exists...
 			bug_ensure_exists( $p_duplicate_id );
@@ -1155,7 +1204,7 @@
 
 		# Add bugnote if supplied
 		if ( !is_blank( $p_bugnote_text ) ) {
-			bugnote_add( $p_bug_id, $p_bugnote_text );
+			bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
 		}
 
 		email_resolved( $p_bug_id );
@@ -1171,7 +1220,7 @@
 
 	# --------------------
 	# reopen the given bug
-	function bug_reopen( $p_bug_id, $p_bugnote_text='' ) {
+	function bug_reopen( $p_bug_id, $p_bugnote_text='', $p_bugnote_private = false ) {
 		$p_bugnote_text = trim( $p_bugnote_text );
 
 		bug_set_field( $p_bug_id, 'status', config_get( 'bug_reopen_status' ) );
@@ -1179,7 +1228,7 @@
 
 		# Add bugnote if supplied
 		if ( !is_blank( $p_bugnote_text ) ) {
-			bugnote_add( $p_bug_id, $p_bugnote_text );
+			bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
 		}
 
 		email_reopen( $p_bug_id );
@@ -1271,35 +1320,37 @@
 	# --------------------
 	# Return a copy of the bug structure with all the instvars prepared for db insertion
 	function bug_prepare_db( $p_bug_data ) {
-		$p_bug_data->project_id			= db_prepare_int( $p_bug_data->project_id );
-		$p_bug_data->reporter_id		= db_prepare_int( $p_bug_data->reporter_id );
-		$p_bug_data->handler_id			= db_prepare_int( $p_bug_data->handler_id );
-		$p_bug_data->duplicate_id		= db_prepare_int( $p_bug_data->duplicate_id );
-		$p_bug_data->priority			= db_prepare_int( $p_bug_data->priority );
-		$p_bug_data->severity			= db_prepare_int( $p_bug_data->severity );
-		$p_bug_data->reproducibility	= db_prepare_int( $p_bug_data->reproducibility );
-		$p_bug_data->status				= db_prepare_int( $p_bug_data->status );
-		$p_bug_data->resolution			= db_prepare_int( $p_bug_data->resolution );
-		$p_bug_data->projection			= db_prepare_int( $p_bug_data->projection );
-		$p_bug_data->category			= db_prepare_string( $p_bug_data->category );
-		$p_bug_data->date_submitted		= db_prepare_string( $p_bug_data->date_submitted );
-		$p_bug_data->last_updated		= db_prepare_string( $p_bug_data->last_updated );
-		$p_bug_data->eta				= db_prepare_int( $p_bug_data->eta );
-		$p_bug_data->os					= db_prepare_string( $p_bug_data->os );
-		$p_bug_data->os_build			= db_prepare_string( $p_bug_data->os_build );
-		$p_bug_data->platform			= db_prepare_string( $p_bug_data->platform );
-		$p_bug_data->version			= db_prepare_string( $p_bug_data->version );
-		$p_bug_data->build				= db_prepare_string( $p_bug_data->build );
-		$p_bug_data->fixed_in_version		= db_prepare_string( $p_bug_data->fixed_in_version );
-		$p_bug_data->view_state			= db_prepare_int( $p_bug_data->view_state );
-		$p_bug_data->summary			= db_prepare_string( $p_bug_data->summary );
-		$p_bug_data->sponsorship_total		= db_prepare_int( $p_bug_data->sponsorship_total );
+		$t_bug_data = new BugData;
+		$t_bug_data->project_id			= db_prepare_int( $p_bug_data->project_id );
+		$t_bug_data->reporter_id		= db_prepare_int( $p_bug_data->reporter_id );
+		$t_bug_data->handler_id			= db_prepare_int( $p_bug_data->handler_id );
+		$t_bug_data->duplicate_id		= db_prepare_int( $p_bug_data->duplicate_id );
+		$t_bug_data->priority			= db_prepare_int( $p_bug_data->priority );
+		$t_bug_data->severity			= db_prepare_int( $p_bug_data->severity );
+		$t_bug_data->reproducibility	= db_prepare_int( $p_bug_data->reproducibility );
+		$t_bug_data->status				= db_prepare_int( $p_bug_data->status );
+		$t_bug_data->resolution			= db_prepare_int( $p_bug_data->resolution );
+		$t_bug_data->projection			= db_prepare_int( $p_bug_data->projection );
+		$t_bug_data->category			= db_prepare_string( $p_bug_data->category );
+		$t_bug_data->date_submitted		= db_prepare_string( $p_bug_data->date_submitted );
+		$t_bug_data->last_updated		= db_prepare_string( $p_bug_data->last_updated );
+		$t_bug_data->eta				= db_prepare_int( $p_bug_data->eta );
+		$t_bug_data->os					= db_prepare_string( $p_bug_data->os );
+		$t_bug_data->os_build			= db_prepare_string( $p_bug_data->os_build );
+		$t_bug_data->platform			= db_prepare_string( $p_bug_data->platform );
+		$t_bug_data->version			= db_prepare_string( $p_bug_data->version );
+		$t_bug_data->build				= db_prepare_string( $p_bug_data->build );
+		$t_bug_data->fixed_in_version	= db_prepare_string( $p_bug_data->fixed_in_version );
+		$t_bug_data->view_state			= db_prepare_int( $p_bug_data->view_state );
+		$t_bug_data->summary			= db_prepare_string( $p_bug_data->summary );
+		$t_bug_data->sponsorship_total	= db_prepare_int( $p_bug_data->sponsorship_total );
+		$t_bug_data->sticky				= db_prepare_int( $p_bug_data->sticky );
 
-		$p_bug_data->description		= db_prepare_string( $p_bug_data->description );
-		$p_bug_data->steps_to_reproduce	= db_prepare_string( $p_bug_data->steps_to_reproduce );
-		$p_bug_data->additional_information	= db_prepare_string( $p_bug_data->additional_information );
+		$t_bug_data->description		= db_prepare_string( $p_bug_data->description );
+		$t_bug_data->steps_to_reproduce	= db_prepare_string( $p_bug_data->steps_to_reproduce );
+		$t_bug_data->additional_information	= db_prepare_string( $p_bug_data->additional_information );
 
-		return $p_bug_data;
+		return $t_bug_data;
 	}
 
 	# --------------------
@@ -1314,9 +1365,10 @@
 		$p_bug_data->platform			= string_attribute( $p_bug_data->platform );
 		$p_bug_data->version			= string_attribute( $p_bug_data->version );
 		$p_bug_data->build				= string_attribute( $p_bug_data->build );
-		$p_bug_data->fixed_in_version		= string_attribute( $p_bug_data->fixed_in_version );
+		$p_bug_data->fixed_in_version	= string_attribute( $p_bug_data->fixed_in_version );
 		$p_bug_data->summary			= string_attribute( $p_bug_data->summary );
-		$p_bug_data->sponsorship_total		= string_attribute( $p_bug_data->sponsorship_total );
+		$p_bug_data->sponsorship_total	= string_attribute( $p_bug_data->sponsorship_total );
+		$p_bug_data->sticky				= string_attribute( $p_bug_data->sticky );
 
 		$p_bug_data->description		= string_textarea( $p_bug_data->description );
 		$p_bug_data->steps_to_reproduce	= string_textarea( $p_bug_data->steps_to_reproduce );
@@ -1337,9 +1389,10 @@
 		$p_bug_data->platform			= string_display( $p_bug_data->platform );
 		$p_bug_data->version			= string_display( $p_bug_data->version );
 		$p_bug_data->build				= string_display( $p_bug_data->build );
-		$p_bug_data->fixed_in_version		= string_display( $p_bug_data->fixed_in_version );
+		$p_bug_data->fixed_in_version	= string_display( $p_bug_data->fixed_in_version );
 		$p_bug_data->summary			= string_display_links( $p_bug_data->summary );
-		$p_bug_data->sponsorship_total		= string_display( $p_bug_data->sponsorship_total );
+		$p_bug_data->sponsorship_total	= string_display( $p_bug_data->sponsorship_total );
+		$p_bug_data->sticky				= string_display( $p_bug_data->sticky );
 
 		$p_bug_data->description		= string_display_links( $p_bug_data->description );
 		$p_bug_data->steps_to_reproduce	= string_display_links( $p_bug_data->steps_to_reproduce );
