@@ -7,7 +7,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: checkin.php,v 1.2 2004/09/30 18:26:38 thraxisp Exp $
+	# $Id: checkin.php,v 1.4.12.1 2006/05/28 14:27:15 vboctor Exp $
 	# --------------------------------------------------------
 
 	global $g_bypass_headers;
@@ -34,8 +34,11 @@
 
 	# Detect references to issues + concat all lines to have the comment log.
 	$t_commit_regexp = config_get( 'source_control_regexp' );
+    $t_commit_fixed_regexp = config_get( 'source_control_fixed_regexp' );
+
 	$t_comment = '';
 	$t_issues = array();
+	$t_fixed_issues = array();
 	while ( ( $t_line = fgets( STDIN, 1024 ) ) ) {
 		$t_comment .= $t_line;
 		if ( preg_match_all( $t_commit_regexp, $t_line, $t_matches ) ) {
@@ -43,10 +46,16 @@
 				$t_issues[] = $t_matches[1][$i];
 			}
 		}
+
+		if ( preg_match_all( $t_commit_fixed_regexp, $t_line, $t_matches) ) {
+			for ( $i = 0; $i < count( $t_matches[0] ); ++$i ) {
+				$t_fixed_issues[] = $t_matches[1][$i];
+			}
+		}
 	}
 
 	# If no issues found, then no work to do.
-	if ( count( $t_issues ) == 0 ) {
+	if ( ( count( $t_issues ) == 0 ) && ( count( $t_fixed_issues ) == 0 ) ) {
 		echo "Comment does not reference any issues.\n";
 		exit(0);
 	}
@@ -61,10 +70,21 @@
 	$t_history_old_value = '';
 	$t_history_new_value = '';
 
+	# add note to each bug only once
+	$t_issues = array_unique( $t_issues );
+	$t_fixed_issues = array_unique( $t_fixed_issues );
+
 	# Call the custom function to register the checkin on each issue.
-	foreach ( $t_issues as $t_issue_id ) { 
-		helper_call_custom_function( 'checkin', array( $t_issue_id, $t_comment, $t_history_old_value, $t_history_new_value ) );
+
+	foreach ( $t_issues as $t_issue_id ) {
+		if ( !in_array( $t_issue_id, $t_fixed_issues ) ) {
+			helper_call_custom_function( 'checkin', array( $t_issue_id, $t_comment, $t_history_old_value, $t_history_new_value, false ) );
+		}
+	}
+
+	foreach ( $t_fixed_issues as $t_issue_id ) {
+		helper_call_custom_function( 'checkin', array( $t_issue_id, $t_comment, $t_history_old_value, $t_history_new_value, true ) );
 	}
 
 	exit( 0 );
-?>
\ No newline at end of file
+?>
