@@ -5,15 +5,25 @@
 //+----------------------------------------------------------------------+
 //| Copyright (c) 1992-2003 Michael Wimmer                               |
 //+----------------------------------------------------------------------+
-//| I don't have the time to read through all the licences to find out   |
-//| what the exactly say. But it's simple. It's free for non commercial  |
-//| projects, but as soon as you make money with it, i want my share :-) |
-//| (License : Free for non-commercial use)                              |
+/*| This program is free software; you can redistribute it and/or modify |
+  | it under the terms of the GNU General Public License as published by |
+  | the Free Software Foundation; either version 2 of the License, or    |
+  | (at your option) any later version.                                  |
+  |                                                                      |
+  | This program is distributed in the hope that it will be useful,      |
+  | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
+  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
+  | GNU General Public License for more details.                         |
+  |                                                                      |
+  | You should have received a copy of the GNU General Public License    |
+  | along with this program; if not, write to the Free Software          |
+  | Foundation, Inc., 51 Franklin St, Fifth Floor,                       |
+  | Boston, MA  02110-1301  USA                                          |
 //+----------------------------------------------------------------------+
 //| Authors: Michael Wimmer <flaimo@gmx.net>                             |
 //+----------------------------------------------------------------------+
 //
-// $Id: class.RSSBuilder.inc.php,v 1.2 2004/06/16 04:29:09 robertjf Exp $
+// $Id$
 
 /**
 * @package RSSBuilder
@@ -1321,15 +1331,19 @@ class RSSBuilder extends RSSBase {
 				break;
 		} // end switch
 	} // end function
+	/**#@-*/
+
+	/**#@+
+	* @return void
+	* @access public
+	* @uses createOutput()
+	*/
 	/**
 	* echos the output
 	*
 	* use this function if you want to directly output the rss stream
 	*
 	* @desc echos the output
-	* @return void
-	* @access public
-	* @uses createOutput()
 	*/
 	function outputRSS($version = '') {
 		if (!isset($this->output)) {
@@ -1732,4 +1746,4 @@ class RSSItem extends RSSBase {
 	} // end function
 	/**#@-*/
 } // end class RSSItem
-?>
\ No newline at end of file
+?>
