@@ -14,7 +14,7 @@
 
 	$t_core_path = config_get( 'core_path' );
 
-	require_once( $t_core_path . 'class.rss20.php' );
+	require_once( $t_core_path . 'class.RSSBuilder.inc.php' );
 	require_once( $t_core_path . 'news_api.php' );
 	require_once( $t_core_path . 'project_api.php' );
 	require_once( $t_core_path . 'print_api.php' );
@@ -33,6 +33,7 @@
 
 	# construct rss file
 
+	$encoding = lang_get( 'charset' );
 	$about = config_get( 'path' );
 	$title = string_rss_links( config_get( 'window_title' ) . ' - ' . lang_get( 'news' ) );
 	$description = $title;
@@ -43,20 +44,46 @@
 
 	# in minutes (only rss 2.0)
 	$cache = '60';
-	
-	$rss = new rssChannel();
-	$rss->feedLink($about);
-	$rss->feedTitle($title);
-	$rss->feedDescription($description);
-	$rss->feedCategory($category);
-	$rss->feedTtl($cache);
-	$rss->feedImage($image_link,'','');
-	
+
+	$rssfile = new RSSBuilder(	$encoding, $about, $title, $description,
+					$image_link, $category, $cache);
+
+	# person, an organization, or a service
+	$publisher = '';
+
+	# person, an organization, or a service
+	$creator = '';
+
+	$date = (string) date( 'r' );
 	$language = lang_get( 'phpmailer_language' );
 	$rights = '';
 
-	$rss->feedLanguage($language);
-	$rss->feedCopyright($rights);
+	# spatial location , temporal period or jurisdiction
+	$coverage = (string) '';
+
+	# person, an organization, or a service
+	$contributor = (string) '';
+
+	$rssfile->setPublisher( $publisher );
+	$rssfile->setCreator( $creator );
+	$rssfile->setRights( $rights );
+	$rssfile->setCoverage( $coverage );
+	$rssfile->setContributor( $contributor );
+
+	# hourly / daily / weekly / ...
+	$period = (string) 'daily';
+
+	# every X hours/days/...
+	$frequency = (int) 1;
+
+	$base = (string) date('Y-m-d\TH:i:sO');
+
+	# add missing : in the O part of the date.  PHP 5 supports a 'c' format which will output the format
+	# exactly as we want it.
+	# // 2002-10-02T10:00:00-0500 -> // 2002-10-02T10:00:00-05:00
+	$base = substr( $base, 0, 22 ) . ':' . substr( $base, -2 );
+
+	$rssfile->addSYdata( $period, $frequency, $base );
 
 	$news_rows = news_get_limited_rows( 0 /* offset */, $f_project_id );
 
@@ -71,9 +98,6 @@
 			continue;
 		}
 
-		$item = new rssItem();
-		$item->Clean();
-
 		$v_headline 	= string_rss_links( $v_headline );
 		$v_body 	= string_rss_links( $v_body );
 		$v_date_posted 	= date( 'Y-m-d\TH:i:sO', $v_date_posted );
@@ -106,21 +130,13 @@
 		# optional mod_im value for dispaying a different pic for every item
 		$image = '';
 
-		$item->itemTitle($title);
-		$item->itemDescription($description);
-		$item->itemLink($link);
-		$item->itemPubdate($date);
-		$item->itemAuthor($author);
-		$item->itemComments($comments);
-
-		$rss->AddItem($item->Create());
-
+		$rssfile->addItem(	$about, $title, $link, $description, $subject, $date,
+					$author, $comments, $image);
 	}
 
 	# @@@ consider making this a configuration option.
 	# 0.91 / 1.0 / 2.0
+	$version = '2.0';
 
-	$rss->Create();
-	$rss->Show();
-
+	$rssfile->outputRSS( $version );
 ?>
